@@ -9,7 +9,6 @@
 @License :  (c)Copyright 2022-2023
 @Desc    :  None
 """
-import sys
 import time
 import threading
 from typing import Union
@@ -120,32 +119,26 @@ class AyuSpider(Spider):
         super(AyuSpider, self).__init__(*args, **kwargs)
         self.mysql_engine = None
 
-    @classmethod
-    def slog_init(cls, level: Union[str, list]) -> None:
+    @property
+    def slog(self):
         """
-        日志全局配置
-
-        can use it directly (e.g. Spider.slog.info('msg'))
-        Almost the same as (spider.logger.info('msg'))
-        loguru 文档中相关介绍:
-            https://loguru.readthedocs.io/en/stable/resources/recipes.html#changing-the-level-of-an-existing-handler
-
-        Args:
-            level: loguru 等级配置参数
-                1. 当参数为 str 时：设置日志等级只输出 level 之上
-                2. 当参数为 list 时：设置日志输出列表中的级别
-
-        Returns:
-            None
+        本库的日志管理模块，使用 loguru 来管理日志；
+        本配置可与 Scrapy 的 spider.log 同时管理，根据场景可以自行配置。
         """
-        assert type(level) in [str, list], "level 参数需要为 str 或 list 格式！"
+        # 设置 loguru 日志配置
+        loguru_config_tmp = self.crawler.settings.get("LOGURU_CONFIG")
+        # 是否开启 loguru 日志记录
+        loguru_enabled = self.crawler.settings.get("LOGURU_ENABLED", True)
+        assert isinstance(loguru_enabled, bool), "loguru_enabled 参数格式需要为 bool"
 
-        # 先删除其它所有的 handle，以防使用本库的其它项目中 loguru 日志配置相互影响
-        logger.remove()
-        if isinstance(level, str):
-            logger.add(sys.stderr, level=level)
+        # 如果开启推荐的 loguru 日志管理功能
+        if loguru_enabled:
+            # 则使用 LOGURU_CONFIG 下的配置，或直接使用统一管理的 logger
+            return loguru_config_tmp or logger
+
+        # 如果关闭推荐的日志管理，则替换为 scrapy 的日志管理
         else:
-            logger.add(sys.stderr, filter=lambda record: record["level"].name in level)
+            return super(AyuSpider, self).logger
 
     @classmethod
     def update_settings(cls, settings):
@@ -242,11 +235,6 @@ class AyuSpider(Spider):
     def from_crawler(cls, crawler, *args, **kwargs):
         spider = super(AyuSpider, cls).from_crawler(crawler, *args, **kwargs)
 
-        # 取出日志等级，同样配置给 loguru
-        normal_logger_level = crawler.settings.get("LOG_LEVEL", "DEBUG")
-        cls.slog_init(level=normal_logger_level)
-        # 将 spider.slog 的日志功能替代为 spider.logger，具有同样功能
-        spider.slog = logger
         # 先输出下相关日志，用于调试时查看
         spider.slog.debug(f"settings_type 配置: {cls.settings_type}")
         spider.slog.debug(f"scrapy 当前配置为: {dict(crawler.settings)}")
